"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.medalists_resolvers import resolve_countries_names_medalists

olympics = {
    "olympics bronze medalists": "فائزون بميداليات برونزية أولمبية",
    "olympics gold medalists": "فائزون بميداليات ذهبية أولمبية",
    "olympics medalists": "فائزون بميداليات أولمبية",
    "olympics medallists": "فائزون بميداليات أولمبية",
    "olympics silver medalists": "فائزون بميداليات فضية أولمبية",
    "summer olympics medallists": "فائزون بميداليات أولمبية صيفية",
    "winter olympics medallists": "فائزون بميداليات أولمبية شتوية",
    "universiade competitors": "منافسون في الألعاب الجامعية",
    "universiade medalists": "فائزون بميداليات الألعاب الجامعية",
    "commonwealth games gold medalists": "فائزون بميداليات ذهبية في ألعاب الكومنولث",
    "olympic medalists": "فائزون بميداليات أولمبية",
    "olympic competitors": "منافسون أولمبيون",
    "olympic silver medalists": "فائزون بميداليات فضية أولمبية",
    "olympic bronze medalists": "فائزون بميداليات برونزية أولمبية",
    "winter olympics medalists": "فائزون بميداليات أولمبية شتوية",
    "summer olympics medalists": "فائزون بميداليات أولمبية صيفية",
    "olympics competitors": "منافسون أولمبيون",
    "african games bronze medalists": "فائزون بميداليات برونزية في الألعاب الإفريقية",
    "african games gold medalists": "فائزون بميداليات ذهبية في الألعاب الإفريقية",
    "african games medalists": "فائزون بميداليات الألعاب الإفريقية",
    "african games medallists": "فائزون بميداليات الألعاب الإفريقية",
    "african games silver medalists": "فائزون بميداليات فضية في الألعاب الإفريقية",
    "asian beach games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية الشاطئية",
    "asian beach games competitors": "منافسون في دورة الألعاب الآسيوية الشاطئية",
    "asian beach games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية الشاطئية",
    "asian beach games medalists": "فائزون بميداليات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games medallists": "فائزون بميداليات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games silver medalists": "فائزون بميداليات فضية في دورة الألعاب الآسيوية الشاطئية",
    "asian games gold medalists": "فائزون بميداليات ذهبية في الألعاب الآسيوية",
    "asian games medalists": "فائزون بميداليات الألعاب الآسيوية",
    "asian games medallists": "فائزون بميداليات الألعاب الآسيوية",
    "asian games silver medalists": "فائزون بميداليات فضية في الألعاب الآسيوية",
    "asian indoor games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games competitors": "منافسون في دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games medalists": "فائزون بميداليات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games medallists": "فائزون بميداليات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games silver medalists": "فائزون بميداليات فضية في دورة الألعاب الآسيوية داخل الصالات",
    "asian para games bronze medalists": "فائزون بميداليات برونزية في الألعاب البارالمبية الآسيوية",
    "asian para games gold medalists": "فائزون بميداليات ذهبية في الألعاب البارالمبية الآسيوية",
    "asian para games medalists": "فائزون بميداليات الألعاب البارالمبية الآسيوية",
    "asian para games medallists": "فائزون بميداليات الألعاب البارالمبية الآسيوية",
    "asian para games silver medalists": "فائزون بميداليات فضية في الألعاب البارالمبية الآسيوية",
    "asian summer games bronze medalists": "فائزون بميداليات برونزية في الألعاب الآسيوية الصيفية",
    "asian summer games competitors": "منافسون في الألعاب الآسيوية الصيفية",
    "asian summer games gold medalists": "فائزون بميداليات ذهبية في الألعاب الآسيوية الصيفية",
    "asian summer games medalists": "فائزون بميداليات الألعاب الآسيوية الصيفية",
    "asian summer games medallists": "فائزون بميداليات الألعاب الآسيوية الصيفية",
    "asian summer games silver medalists": "فائزون بميداليات فضية في الألعاب الآسيوية الصيفية",
    "asian winter games bronze medalists": "فائزون بميداليات برونزية في الألعاب الآسيوية الشتوية",
    "asian winter games competitors": "منافسون في الألعاب الآسيوية الشتوية",
    "asian winter games gold medalists": "فائزون بميداليات ذهبية في الألعاب الآسيوية الشتوية",
    "asian winter games medalists": "فائزون بميداليات الألعاب الآسيوية الشتوية",
    "asian winter games medallists": "فائزون بميداليات الألعاب الآسيوية الشتوية",
    "asian winter games silver medalists": "فائزون بميداليات فضية في الألعاب الآسيوية الشتوية",
    "bolivarian games bronze medalists": "فائزون بميداليات برونزية في الألعاب البوليفارية",
    "bolivarian games competitors": "منافسون في الألعاب البوليفارية",
    "bolivarian games gold medalists": "فائزون بميداليات ذهبية في الألعاب البوليفارية",
    "bolivarian games medalists": "فائزون بميداليات الألعاب البوليفارية",
    "bolivarian games medallists": "فائزون بميداليات الألعاب البوليفارية",
    "bolivarian games silver medalists": "فائزون بميداليات فضية في الألعاب البوليفارية",
    "central american and caribbean games bronze medalists": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games gold medalists": "فائزون بميداليات ذهبية في ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games medalists": "فائزون بميداليات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games medallists": "فائزون بميداليات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games silver medalists": "فائزون بميداليات فضية في ألعاب أمريكا الوسطى والكاريبي",
    "central american games bronze medalists": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى",
    "central american games competitors": "منافسون في ألعاب أمريكا الوسطى",
    "central american games gold medalists": "فائزون بميداليات ذهبية في ألعاب أمريكا الوسطى",
    "central american games medalists": "فائزون بميداليات ألعاب أمريكا الوسطى",
    "central american games medallists": "فائزون بميداليات ألعاب أمريكا الوسطى",
    "central american games silver medalists": "فائزون بميداليات فضية في ألعاب أمريكا الوسطى",
    "commonwealth games bronze medalists": "فائزون بميداليات برونزية في ألعاب الكومنولث",
    "commonwealth games medalists": "فائزون بميداليات ألعاب الكومنولث",
    "commonwealth games medallists": "فائزون بميداليات ألعاب الكومنولث",
    "commonwealth games silver medalists": "فائزون بميداليات فضية في ألعاب الكومنولث",
    "commonwealth youth games bronze medalists": "فائزون بميداليات برونزية في ألعاب الكومنولث الشبابية",
    "commonwealth youth games competitors": "منافسون في ألعاب الكومنولث الشبابية",
    "commonwealth youth games gold medalists": "فائزون بميداليات ذهبية في ألعاب الكومنولث الشبابية",
    "commonwealth youth games medalists": "فائزون بميداليات ألعاب الكومنولث الشبابية",
    "commonwealth youth games medallists": "فائزون بميداليات ألعاب الكومنولث الشبابية",
    "commonwealth youth games silver medalists": "فائزون بميداليات فضية في ألعاب الكومنولث الشبابية",
    "deaflympic games bronze medalists": "فائزون بميداليات برونزية في ألعاب ديفلمبياد",
    "deaflympic games competitors": "منافسون في ألعاب ديفلمبياد",
    "deaflympic games gold medalists": "فائزون بميداليات ذهبية في ألعاب ديفلمبياد",
    "deaflympic games medalists": "فائزون بميداليات ألعاب ديفلمبياد",
    "deaflympic games medallists": "فائزون بميداليات ألعاب ديفلمبياد",
    "deaflympic games silver medalists": "فائزون بميداليات فضية في ألعاب ديفلمبياد",
    "european games bronze medalists": "فائزون بميداليات برونزية في الألعاب الأوروبية",
    "european games gold medalists": "فائزون بميداليات ذهبية في الألعاب الأوروبية",
    "european games medalists": "فائزون بميداليات الألعاب الأوروبية",
    "european games medallists": "فائزون بميداليات الألعاب الأوروبية",
    "european games silver medalists": "فائزون بميداليات فضية في الألعاب الأوروبية",
    "european youth olympic bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic competitors": "منافسون في الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic medalists": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic medallists": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic winter bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter competitors": "منافسون في الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter medalists": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter medallists": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "fis nordic world ski championships bronze medalists": "فائزون بميداليات برونزية في بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships competitors": "منافسون في بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships gold medalists": "فائزون بميداليات ذهبية في بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships medalists": "فائزون بميداليات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships medallists": "فائزون بميداليات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships silver medalists": "فائزون بميداليات فضية في بطولة العالم للتزلج النوردي على الثلج",
    "friendship games bronze medalists": "فائزون بميداليات برونزية في ألعاب الصداقة",
    "friendship games competitors": "منافسون في ألعاب الصداقة",
    "friendship games gold medalists": "فائزون بميداليات ذهبية في ألعاب الصداقة",
    "friendship games medalists": "فائزون بميداليات ألعاب الصداقة",
    "friendship games medallists": "فائزون بميداليات ألعاب الصداقة",
    "friendship games silver medalists": "فائزون بميداليات فضية في ألعاب الصداقة",
    "goodwill games bronze medalists": "فائزون بميداليات برونزية في ألعاب النوايا الحسنة",
    "goodwill games competitors": "منافسون في ألعاب النوايا الحسنة",
    "goodwill games gold medalists": "فائزون بميداليات ذهبية في ألعاب النوايا الحسنة",
    "goodwill games medalists": "فائزون بميداليات ألعاب النوايا الحسنة",
    "goodwill games medallists": "فائزون بميداليات ألعاب النوايا الحسنة",
    "goodwill games silver medalists": "فائزون بميداليات فضية في ألعاب النوايا الحسنة",
    "islamic solidarity games bronze medalists": "فائزون بميداليات برونزية في ألعاب التضامن الإسلامي",
    "islamic solidarity games gold medalists": "فائزون بميداليات ذهبية في ألعاب التضامن الإسلامي",
    "islamic solidarity games medalists": "فائزون بميداليات ألعاب التضامن الإسلامي",
    "islamic solidarity games medallists": "فائزون بميداليات ألعاب التضامن الإسلامي",
    "islamic solidarity games silver medalists": "فائزون بميداليات فضية في ألعاب التضامن الإسلامي",
    "maccabiah games bronze medalists": "فائزون بميداليات برونزية في الألعاب المكابيه",
    "maccabiah games gold medalists": "فائزون بميداليات ذهبية في الألعاب المكابيه",
    "maccabiah games medalists": "فائزون بميداليات الألعاب المكابيه",
    "maccabiah games medallists": "فائزون بميداليات الألعاب المكابيه",
    "maccabiah games silver medalists": "فائزون بميداليات فضية في الألعاب المكابيه",
    "mediterranean games bronze medalists": "فائزون بميداليات برونزية في الألعاب المتوسطية",
    "mediterranean games gold medalists": "فائزون بميداليات ذهبية في الألعاب المتوسطية",
    "mediterranean games medalists": "فائزون بميداليات الألعاب المتوسطية",
    "mediterranean games medallists": "فائزون بميداليات الألعاب المتوسطية",
    "mediterranean games silver medalists": "فائزون بميداليات فضية في الألعاب المتوسطية",
    "micronesian games bronze medalists": "فائزون بميداليات برونزية في الألعاب الميكرونيزية",
    "micronesian games competitors": "منافسون في الألعاب الميكرونيزية",
    "micronesian games gold medalists": "فائزون بميداليات ذهبية في الألعاب الميكرونيزية",
    "micronesian games medalists": "فائزون بميداليات الألعاب الميكرونيزية",
    "micronesian games medallists": "فائزون بميداليات الألعاب الميكرونيزية",
    "micronesian games silver medalists": "فائزون بميداليات فضية في الألعاب الميكرونيزية",
    "military world games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب العسكرية",
    "military world games competitors": "منافسون في دورة الألعاب العسكرية",
    "military world games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب العسكرية",
    "military world games medalists": "فائزون بميداليات دورة الألعاب العسكرية",
    "military world games medallists": "فائزون بميداليات دورة الألعاب العسكرية",
    "military world games silver medalists": "فائزون بميداليات فضية في دورة الألعاب العسكرية",
    "pan american games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب الأمريكية",
    "pan american games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب الأمريكية",
    "pan american games medalists": "فائزون بميداليات دورة الألعاب الأمريكية",
    "pan american games medallists": "فائزون بميداليات دورة الألعاب الأمريكية",
    "pan american games silver medalists": "فائزون بميداليات فضية في دورة الألعاب الأمريكية",
    "pan arab games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب العربية",
    "pan arab games competitors": "منافسون في دورة الألعاب العربية",
    "pan arab games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب العربية",
    "pan arab games medalists": "فائزون بميداليات دورة الألعاب العربية",
    "pan arab games medallists": "فائزون بميداليات دورة الألعاب العربية",
    "pan arab games silver medalists": "فائزون بميداليات فضية في دورة الألعاب العربية",
    "pan asian games bronze medalists": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية",
    "pan asian games competitors": "منافسون في دورة الألعاب الآسيوية",
    "pan asian games gold medalists": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية",
    "pan asian games medalists": "فائزون بميداليات دورة الألعاب الآسيوية",
    "pan asian games medallists": "فائزون بميداليات دورة الألعاب الآسيوية",
    "pan asian games silver medalists": "فائزون بميداليات فضية في دورة الألعاب الآسيوية",
    "paralympic bronze medalists": "فائزون بميداليات برونزية في الألعاب البارالمبية",
    "paralympic gold medalists": "فائزون بميداليات ذهبية في الألعاب البارالمبية",
    "paralympic medalists": "فائزون بميداليات الألعاب البارالمبية",
    "paralympic medallists": "فائزون بميداليات الألعاب البارالمبية",
    "paralympic silver medalists": "فائزون بميداليات فضية في الألعاب البارالمبية",
    "paralympics bronze medalists": "فائزون بميداليات برونزية في الألعاب البارالمبية",
    "paralympics competitors": "منافسون في الألعاب البارالمبية",
    "paralympics gold medalists": "فائزون بميداليات ذهبية في الألعاب البارالمبية",
    "paralympics medalists": "فائزون بميداليات الألعاب البارالمبية",
    "paralympics medallists": "فائزون بميداليات الألعاب البارالمبية",
    "paralympics silver medalists": "فائزون بميداليات فضية في الألعاب البارالمبية",
    "parapan american games bronze medalists": "فائزون بميداليات برونزية في ألعاب بارابان الأمريكية",
    "parapan american games gold medalists": "فائزون بميداليات ذهبية في ألعاب بارابان الأمريكية",
    "parapan american games medalists": "فائزون بميداليات ألعاب بارابان الأمريكية",
    "parapan american games medallists": "فائزون بميداليات ألعاب بارابان الأمريكية",
    "parapan american games silver medalists": "فائزون بميداليات فضية في ألعاب بارابان الأمريكية",
    "sea games bronze medalists": "فائزون بميداليات برونزية في ألعاب البحر",
    "sea games gold medalists": "فائزون بميداليات ذهبية في ألعاب البحر",
    "sea games medalists": "فائزون بميداليات ألعاب البحر",
    "sea games medallists": "فائزون بميداليات ألعاب البحر",
    "sea games silver medalists": "فائزون بميداليات فضية في ألعاب البحر",
    "south american games bronze medalists": "فائزون بميداليات برونزية في ألعاب أمريكا الجنوبية",
    "south american games gold medalists": "فائزون بميداليات ذهبية في ألعاب أمريكا الجنوبية",
    "south american games medalists": "فائزون بميداليات ألعاب أمريكا الجنوبية",
    "south american games medallists": "فائزون بميداليات ألعاب أمريكا الجنوبية",
    "south american games silver medalists": "فائزون بميداليات فضية في ألعاب أمريكا الجنوبية",
    "south asian beach games bronze medalists": "فائزون بميداليات برونزية في دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games competitors": "منافسون في دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games gold medalists": "فائزون بميداليات ذهبية في دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games medalists": "فائزون بميداليات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games medallists": "فائزون بميداليات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games silver medalists": "فائزون بميداليات فضية في دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games bronze medalists": "فائزون بميداليات برونزية في ألعاب جنوب أسيا",
    "south asian games competitors": "منافسون في ألعاب جنوب أسيا",
    "south asian games gold medalists": "فائزون بميداليات ذهبية في ألعاب جنوب أسيا",
    "south asian games medalists": "فائزون بميداليات ألعاب جنوب أسيا",
    "south asian games medallists": "فائزون بميداليات ألعاب جنوب أسيا",
    "south asian games silver medalists": "فائزون بميداليات فضية في ألعاب جنوب أسيا",
    "south asian winter games bronze medalists": "فائزون بميداليات برونزية في ألعاب جنوب آسيا الشتوية",
    "south asian winter games competitors": "منافسون في ألعاب جنوب آسيا الشتوية",
    "south asian winter games gold medalists": "فائزون بميداليات ذهبية في ألعاب جنوب آسيا الشتوية",
    "south asian winter games medalists": "فائزون بميداليات ألعاب جنوب آسيا الشتوية",
    "south asian winter games medallists": "فائزون بميداليات ألعاب جنوب آسيا الشتوية",
    "south asian winter games silver medalists": "فائزون بميداليات فضية في ألعاب جنوب آسيا الشتوية",
    "southeast asian games bronze medalists": "فائزون بميداليات برونزية في ألعاب جنوب شرق آسيا",
    "southeast asian games competitors": "منافسون في ألعاب جنوب شرق آسيا",
    "southeast asian games gold medalists": "فائزون بميداليات ذهبية في ألعاب جنوب شرق آسيا",
    "southeast asian games medalists": "فائزون بميداليات ألعاب جنوب شرق آسيا",
    "southeast asian games medallists": "فائزون بميداليات ألعاب جنوب شرق آسيا",
    "southeast asian games silver medalists": "فائزون بميداليات فضية في ألعاب جنوب شرق آسيا",
    "summer olympics bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الصيفية",
    "summer olympics gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الصيفية",
    "summer olympics silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الصيفية",
    "summer universiade bronze medalists": "فائزون بميداليات برونزية في الألعاب الجامعية الصيفية",
    "summer universiade competitors": "منافسون في الألعاب الجامعية الصيفية",
    "summer universiade gold medalists": "فائزون بميداليات ذهبية في الألعاب الجامعية الصيفية",
    "summer universiade medalists": "فائزون بميداليات الألعاب الجامعية الصيفية",
    "summer universiade medallists": "فائزون بميداليات الألعاب الجامعية الصيفية",
    "summer universiade silver medalists": "فائزون بميداليات فضية في الألعاب الجامعية الصيفية",
    "summer world university games bronze medalists": "فائزون بميداليات برونزية في ألعاب الجامعات العالمية الصيفية",
    "summer world university games gold medalists": "فائزون بميداليات ذهبية في ألعاب الجامعات العالمية الصيفية",
    "summer world university games medalists": "فائزون بميداليات ألعاب الجامعات العالمية الصيفية",
    "summer world university games medallists": "فائزون بميداليات ألعاب الجامعات العالمية الصيفية",
    "summer world university games silver medalists": "فائزون بميداليات فضية في ألعاب الجامعات العالمية الصيفية",
    "the universiade bronze medalists": "فائزون بميداليات برونزية في الألعاب الجامعية",
    "the universiade competitors": "منافسون في الألعاب الجامعية",
    "the universiade gold medalists": "فائزون بميداليات ذهبية في الألعاب الجامعية",
    "the universiade medalists": "فائزون بميداليات الألعاب الجامعية",
    "the universiade medallists": "فائزون بميداليات الألعاب الجامعية",
    "the universiade silver medalists": "فائزون بميداليات فضية في الألعاب الجامعية",
    "universiade bronze medalists": "فائزون بميداليات برونزية في الألعاب الجامعية",
    "universiade gold medalists": "فائزون بميداليات ذهبية في الألعاب الجامعية",
    "universiade medallists": "فائزون بميداليات الألعاب الجامعية",
    "universiade silver medalists": "فائزون بميداليات فضية في الألعاب الجامعية",
    "winter olympics bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشتوية",
    "winter olympics gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشتوية",
    "winter olympics silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشتوية",
    "winter universiade bronze medalists": "فائزون بميداليات برونزية في الألعاب الجامعية الشتوية",
    "winter universiade competitors": "منافسون في الألعاب الجامعية الشتوية",
    "winter universiade gold medalists": "فائزون بميداليات ذهبية في الألعاب الجامعية الشتوية",
    "winter universiade medalists": "فائزون بميداليات الألعاب الجامعية الشتوية",
    "winter universiade medallists": "فائزون بميداليات الألعاب الجامعية الشتوية",
    "winter universiade silver medalists": "فائزون بميداليات فضية في الألعاب الجامعية الشتوية",
    "winter world university games bronze medalists": "فائزون بميداليات برونزية في ألعاب الجامعات العالمية الشتوية",
    "winter world university games competitors": "منافسون في ألعاب الجامعات العالمية الشتوية",
    "winter world university games gold medalists": "فائزون بميداليات ذهبية في ألعاب الجامعات العالمية الشتوية",
    "winter world university games medalists": "فائزون بميداليات ألعاب الجامعات العالمية الشتوية",
    "winter world university games medallists": "فائزون بميداليات ألعاب الجامعات العالمية الشتوية",
    "winter world university games silver medalists": "فائزون بميداليات فضية في ألعاب الجامعات العالمية الشتوية",
    "world athletics indoor championships bronze medalists": "فائزون بميداليات برونزية في بطولة العالم لألعاب القوى داخل الصالات",
    "world athletics indoor championships competitors": "منافسون في بطولة العالم لألعاب القوى داخل الصالات",
    "world athletics indoor championships gold medalists": "فائزون بميداليات ذهبية في بطولة العالم لألعاب القوى داخل الصالات",
    "world athletics indoor championships medalists": "فائزون بميداليات بطولة العالم لألعاب القوى داخل الصالات",
    "world athletics indoor championships medallists": "فائزون بميداليات بطولة العالم لألعاب القوى داخل الصالات",
    "world athletics indoor championships silver medalists": "فائزون بميداليات فضية في بطولة العالم لألعاب القوى داخل الصالات",
    "world championships bronze medalists": "فائزون بميداليات برونزية في بطولات العالم",
    "world championships competitors": "منافسون في بطولات العالم",
    "world championships gold medalists": "فائزون بميداليات ذهبية في بطولات العالم",
    "world championships medalists": "فائزون بميداليات بطولات العالم",
    "world championships medallists": "فائزون بميداليات بطولات العالم",
    "world championships silver medalists": "فائزون بميداليات فضية في بطولات العالم",
    "youth olympic bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية",
    "youth olympic competitors": "منافسون في الألعاب الأولمبية الشبابية",
    "youth olympic gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية",
    "youth olympic medalists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympic medallists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympic silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية",
    "youth olympics bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية",
    "youth olympics competitors": "منافسون في الألعاب الأولمبية الشبابية",
    "youth olympics games bronze medalists": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية",
    "youth olympics games competitors": "منافسون في الألعاب الأولمبية الشبابية",
    "youth olympics games gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية",
    "youth olympics games medalists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympics games medallists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympics games silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية",
    "youth olympics gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية",
    "youth olympics medalists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympics medallists": "فائزون بميداليات الألعاب الأولمبية الشبابية",
    "youth olympics silver medalists": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية",
}

for_countries = {
    "Category:Winter Olympics competitors": "تصنيف:منافسون أولمبيون شتويون",
    "Category:Winter Olympics competitors for Algeria": "تصنيف:منافسون أولمبيون شتويون من الجزائر",
    "Category:Winter Olympics competitors for Andorra": "تصنيف:منافسون أولمبيون شتويون من أندورا",
    "Category:Winter Olympics competitors for Australia": "تصنيف:منافسون أولمبيون شتويون من أستراليا",
    "Category:Winter Olympics competitors for Austria": "تصنيف:منافسون أولمبيون شتويون من النمسا",
    "Category:Winter Olympics competitors for Belarus": "تصنيف:منافسون أولمبيون شتويون من روسيا البيضاء",
    "Category:Winter Olympics competitors for Canada": "تصنيف:منافسون أولمبيون شتويون من كندا",
    "Category:Winter Olympics competitors for China": "تصنيف:منافسون أولمبيون شتويون من الصين",
    "Category:Winter Olympics competitors for Croatia": "تصنيف:منافسون أولمبيون شتويون من كرواتيا",
    "Category:Winter Olympics competitors for Czechoslovakia": "تصنيف:منافسون أولمبيون شتويون من تشيكوسلوفاكيا",
    "Category:Winter Olympics competitors for East Germany": "تصنيف:منافسون أولمبيون شتويون من ألمانيا الشرقية",
    "Category:Winter Olympics competitors for Egypt": "تصنيف:منافسون أولمبيون شتويون من مصر",
    "Category:Winter Olympics competitors for Finland": "تصنيف:منافسون أولمبيون شتويون من فنلندا",
    "Category:Winter Olympics competitors for France": "تصنيف:منافسون أولمبيون شتويون من فرنسا",
    "Category:Winter Olympics competitors for Germany": "تصنيف:منافسون أولمبيون شتويون من ألمانيا",
    "Category:Winter Olympics competitors for Great Britain": "تصنيف:منافسون أولمبيون شتويون من بريطانيا العظمى",
    "Category:Winter Olympics competitors for Iran": "تصنيف:منافسون أولمبيون شتويون من إيران",
    "Category:Winter Olympics competitors for Italy": "تصنيف:منافسون أولمبيون شتويون من إيطاليا",
    "Category:Winter Olympics competitors for Japan": "تصنيف:منافسون أولمبيون شتويون من اليابان",
    "Category:Winter Olympics competitors for Kazakhstan": "تصنيف:منافسون أولمبيون شتويون من كازاخستان",
    "Category:Winter Olympics competitors for Latvia": "تصنيف:منافسون أولمبيون شتويون من لاتفيا",
    "Category:Winter Olympics competitors for Lebanon": "تصنيف:منافسون أولمبيون شتويون من لبنان",
    "Category:Winter Olympics competitors for Moldova": "تصنيف:منافسون أولمبيون شتويون من مولدوفا",
    "Category:Winter Olympics competitors for Morocco": "تصنيف:منافسون أولمبيون شتويون من المغرب",
    "Category:Winter Olympics competitors for Norway": "تصنيف:منافسون أولمبيون شتويون من النرويج",
    "Category:Winter Olympics competitors for Romania": "تصنيف:منافسون أولمبيون شتويون من رومانيا",
    "Category:Winter Olympics competitors for Russia": "تصنيف:منافسون أولمبيون شتويون من روسيا",
    "Category:Winter Olympics competitors for South Korea": "تصنيف:منافسون أولمبيون شتويون من كوريا الجنوبية",
    "Category:Winter Olympics competitors for Sweden": "تصنيف:منافسون أولمبيون شتويون من السويد",
    "Category:Winter Olympics competitors for Switzerland": "تصنيف:منافسون أولمبيون شتويون من سويسرا",
    "Category:Winter Olympics competitors for Thailand": "تصنيف:منافسون أولمبيون شتويون من تايلاند",
    "Category:Winter Olympics competitors for West Germany": "تصنيف:منافسون أولمبيون شتويون من ألمانيا الغربية",
    "Category:Winter Olympics competitors for Yugoslavia": "تصنيف:منافسون أولمبيون شتويون من يوغسلافيا",
    "Category:Winter Olympics competitors for the Czech Republic": "تصنيف:منافسون أولمبيون شتويون من التشيك",
    "Category:Winter Olympics competitors for the Netherlands": "تصنيف:منافسون أولمبيون شتويون من هولندا",
    "Category:Winter Olympics competitors for the Soviet Union": "تصنيف:منافسون أولمبيون شتويون من الاتحاد السوفيتي",
    "Category:Winter Olympics competitors for the United States": "تصنيف:منافسون أولمبيون شتويون من الولايات المتحدة",
}


@pytest.mark.parametrize("category, expected", olympics.items(), ids=olympics.keys())
@pytest.mark.fast
def test_olympics(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", for_countries.items(), ids=for_countries.keys())
@pytest.mark.fast
def test_for_countries(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_olympics", olympics, resolve_countries_names_medalists),
    ("test_for_countries", for_countries, resolve_countries_names_medalists),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
